@@ -5,7 +5,7 @@ use locale;
 use Moo;
 extends 'Org::Element';
 
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 has link => (is => 'rw');
 has description => (is => 'rw');
@@ -18,7 +18,7 @@ sub as_string {
          "[",
          "[", $self->link, "]",
          (defined($self->description) && length($self->description) ?
-              ("[", $self->description, "]") : ()),
+              ("[", $self->description->as_string, "]") : ()),
          "]");
 }
 
@@ -34,7 +34,7 @@ Org::Element::Link - Represent Org hyperlink
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 DESCRIPTION
 
@@ -58,7 +58,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
